@@ -21,12 +21,12 @@
     <message>
         <location filename="../mainwindow.ui" line="56"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="88"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>הצגת עזרה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="91"/>
@@ -36,7 +36,7 @@
     <message>
         <location filename="../mainwindow.ui" line="98"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="114"/>
@@ -61,7 +61,7 @@
     <message>
         <location filename="../mainwindow.ui" line="208"/>
         <source>Alt+B</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="239"/>
@@ -158,17 +158,17 @@
     <message>
         <location filename="../mainwindow.ui" line="462"/>
         <source>exfat</source>
-        <translation type="unfinished"></translation>
+        <translation>exfat</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="467"/>
         <source>ext4</source>
-        <translation type="unfinished"></translation>
+        <translation>ext4</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="472"/>
         <source>ntfs</source>
-        <translation type="unfinished"></translation>
+        <translation>ntfs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="493"/>
@@ -178,7 +178,7 @@
     <message>
         <location filename="../mainwindow.ui" line="500"/>
         <source>Format</source>
-        <translation type="unfinished"></translation>
+        <translation>פרמוט</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="510"/>
@@ -219,7 +219,7 @@
     <message>
         <location filename="../mainwindow.ui" line="634"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>אפשרויות</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="669"/>
@@ -281,7 +281,7 @@
         <location filename="../mainwindow.cpp" line="304"/>
         <location filename="../mainwindow.cpp" line="443"/>
         <source>Failure</source>
-        <translation type="unfinished"></translation>
+        <translation>כשל</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="110"/>
@@ -298,7 +298,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
         <source>Success</source>
-        <translation type="unfinished"></translation>
+        <translation>הצלחה</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
@@ -406,7 +406,7 @@ Please wait until the the process is completed</source>
         <location filename="../about.cpp" line="33"/>
         <location filename="../about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>יומן שינויים</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="34"/>
@@ -416,17 +416,17 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;סגירה</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="73"/>
         <source>Error</source>
-        <translation type="unfinished">תקלה</translation>
+        <translation>שגיאה</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="74"/>
         <source>You must run this program as root.</source>
-        <translation>אתה חייב להריץ את התוכנה הזו עם הרשאות root.</translation>
+        <translation>יש להריץ את התכנית הזו כמשתמש על.</translation>
     </message>
 </context>
 </TS>
