@@ -153,7 +153,7 @@
     <message>
         <location filename="../mainwindow.ui" line="457"/>
         <source>vfat</source>
-        <translation type="unfinished"></translation>
+        <translation>vfat</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="462"/>
@@ -189,12 +189,12 @@
         <location filename="../mainwindow.ui" line="524"/>
         <location filename="../mainwindow.cpp" line="458"/>
         <source>Show advanced options</source>
-        <translation type="unfinished"></translation>
+        <translation>Gelişmiş seçenekleri göster</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="544"/>
         <source>Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Kip</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="559"/>
@@ -214,7 +214,7 @@
     <message>
         <location filename="../mainwindow.ui" line="586"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
-        <translation type="unfinished"></translation>
+        <translation>AntiX / MX dışındaki dağıtımlar için (dd) kalıp kipini kullanın.</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="634"/>
@@ -259,7 +259,7 @@
     <message>
         <location filename="../mainwindow.ui" line="747"/>
         <source>Encrypt</source>
-        <translation type="unfinished"></translation>
+        <translation>Şifrele</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="754"/>
@@ -269,7 +269,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="74"/>
         <source>Confirmation</source>
-        <translation type="unfinished"></translation>
+        <translation>Onay</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="74"/>
@@ -329,7 +329,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="403"/>
         <source>About %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Hakkında %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="404"/>
@@ -349,12 +349,12 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="408"/>
         <source>%1 License</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 Telif Hakkı</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="416"/>
         <source>%1 Help</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 Yardım</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="427"/>
@@ -370,23 +370,23 @@ Please wait until the the process is completed</source>
         <location filename="../mainwindow.cpp" line="437"/>
         <location filename="../mainwindow.cpp" line="509"/>
         <source>Select Source Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Kaynak Dizini Seçin</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="443"/>
         <source>Could not find %1/antiX/linuxfs file</source>
-        <translation type="unfinished"></translation>
+        <translation>%1/antiX/linuxfs dosyası bulunamadı</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="464"/>
         <source>Hide advanced options</source>
-        <translation type="unfinished"></translation>
+        <translation>Gelişmiş seçenekleri gizle</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="508"/>
         <location filename="../mainwindow.cpp" line="525"/>
         <source>Select Source</source>
-        <translation type="unfinished"></translation>
+        <translation>Kaynak Seçin</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="512"/>
@@ -421,7 +421,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../main.cpp" line="73"/>
         <source>Error</source>
-        <translation type="unfinished">Hata</translation>
+        <translation>Hata</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="74"/>
